package com.chelvc.framework.database.crypto;

import javax.crypto.Cipher;

import com.chelvc.framework.common.util.AESUtils;
import com.chelvc.framework.common.util.CodecUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.database.config.DatabaseProperties;
import lombok.NonNull;

/**
 * 数据库加解密处理默认实现
 *
 * @author Woody
 * @date 2024/12/27
 */
public class DefaultDatabaseCipherHandler implements DatabaseCipherHandler {
    private final boolean mixed, writable;
    protected final Cipher encryptor, decrypter;

    public DefaultDatabaseCipherHandler(@NonNull DatabaseProperties.Crypto properties) {
        this.mixed = properties.isMixed();
        this.writable = properties.isWritable();
        this.encryptor = StringUtils.ifEmpty(
                properties.getSecret(), secret -> AESUtils.getEncryptor(AESUtils.ECB_PKCS5PADDING, secret)
        );
        this.decrypter = StringUtils.ifEmpty(
                properties.getSecret(), secret -> AESUtils.getDecrypter(AESUtils.ECB_PKCS5PADDING, secret)
        );
    }

    @Override
    public boolean isMixed() {
        return this.mixed;
    }

    @Override
    public boolean isWritable() {
        return this.writable;
    }

    @Override
    public byte[] encrypt(byte[] bytes) {
        return CodecUtils.codec(this.encryptor, bytes);
    }

    @Override
    public byte[] decrypt(byte[] bytes) {
        return CodecUtils.codec(this.decrypter, bytes);
    }
}
